# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/http_connection_manager/v2/http_connection_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import protocol_pb2 as envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2
from envoy.api.v2 import route_pb2 as envoy_dot_api_dot_v2_dot_route__pb2
from envoy.api.v2 import scoped_route_pb2 as envoy_dot_api_dot_v2_dot_scoped__route__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from envoy.type.tracing.v2 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v2_dot_custom__tag__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/http_connection_manager/v2/http_connection_manager.proto',
  package='envoy.config.filter.network.http_connection_manager.v2',
  syntax='proto3',
  serialized_options=b'\nDio.envoyproxy.envoy.config.filter.network.http_connection_manager.v2B\032HttpConnectionManagerProtoP\001\362\230\376\217\005=\022;envoy.extensions.filters.network.http_connection_manager.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nTenvoy/config/filter/network/http_connection_manager/v2/http_connection_manager.proto\x12\x36\x65nvoy.config.filter.network.http_connection_manager.v2\x1a%envoy/api/v2/core/config_source.proto\x1a envoy/api/v2/core/protocol.proto\x1a\x18\x65nvoy/api/v2/route.proto\x1a\x1f\x65nvoy/api/v2/scoped_route.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a\x18\x65nvoy/type/percent.proto\x1a&envoy/type/tracing/v2/custom_tag.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfe\x1c\n\x15HttpConnectionManager\x12u\n\ncodec_type\x18\x01 \x01(\x0e\x32W.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.CodecTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12J\n\x03rds\x18\x03 \x01(\x0b\x32;.envoy.config.filter.network.http_connection_manager.v2.RdsH\x00\x12\x38\n\x0croute_config\x18\x04 \x01(\x0b\x32 .envoy.api.v2.RouteConfigurationH\x00\x12]\n\rscoped_routes\x18\x1f \x01(\x0b\x32\x44.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutesH\x00\x12X\n\x0chttp_filters\x18\x05 \x03(\x0b\x32\x42.envoy.config.filter.network.http_connection_manager.v2.HttpFilter\x12\x32\n\x0e\x61\x64\x64_user_agent\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x66\n\x07tracing\x18\x07 \x01(\x0b\x32U.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing\x12L\n\x1c\x63ommon_http_protocol_options\x18# \x01(\x0b\x32&.envoy.api.v2.core.HttpProtocolOptions\x12\x46\n\x15http_protocol_options\x18\x08 \x01(\x0b\x32\'.envoy.api.v2.core.Http1ProtocolOptions\x12G\n\x16http2_protocol_options\x18\t \x01(\x0b\x32\'.envoy.api.v2.core.Http2ProtocolOptions\x12\x13\n\x0bserver_name\x18\n \x01(\t\x12\x98\x01\n\x1cserver_header_transformation\x18\" \x01(\x0e\x32h.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ServerHeaderTransformationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n\x16max_request_headers_kb\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18` \x00\x12\x39\n\x0cidle_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x36\n\x13stream_idle_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0frequest_timeout\x18\x1c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\rdrain_timeout\x18\x0c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15\x64\x65layed_close_timeout\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12?\n\naccess_log\x18\r \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x12\x36\n\x12use_remote_address\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1c\n\x14xff_num_trusted_hops\x18\x13 \x01(\r\x12\x84\x01\n\x17internal_address_config\x18\x19 \x01(\x0b\x32\x63.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.InternalAddressConfig\x12\x17\n\x0fskip_xff_append\x18\x15 \x01(\x08\x12\x0b\n\x03via\x18\x16 \x01(\t\x12\x37\n\x13generate_request_id\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12$\n\x1cpreserve_external_request_id\x18  \x01(\x08\x12\x95\x01\n\x1b\x66orward_client_cert_details\x18\x10 \x01(\x0e\x32\x66.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ForwardClientCertDetailsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x92\x01\n\x1fset_current_client_cert_details\x18\x11 \x01(\x0b\x32i.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails\x12\x1a\n\x12proxy_100_continue\x18\x12 \x01(\x08\x12\x39\n1represent_ipv4_remote_address_as_ipv4_mapped_ipv6\x18\x14 \x01(\x08\x12t\n\x0fupgrade_configs\x18\x17 \x03(\x0b\x32[.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig\x12\x32\n\x0enormalize_path\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rmerge_slashes\x18! \x01(\x08\x12h\n\x14request_id_extension\x18$ \x01(\x0b\x32J.envoy.config.filter.network.http_connection_manager.v2.RequestIDExtension\x1a\xae\x04\n\x07Tracing\x12\x8d\x01\n\x0eoperation_name\x18\x01 \x01(\x0e\x32\x63.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.OperationNameB\x10\x18\x01\xfa\x42\x05\x82\x01\x02\x10\x01\xb8\xee\xf2\xd2\x05\x01\x12$\n\x18request_headers_for_tags\x18\x02 \x03(\tB\x02\x18\x01\x12,\n\x0f\x63lient_sampling\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12,\n\x0frandom_sampling\x18\x04 \x01(\x0b\x32\x13.envoy.type.Percent\x12-\n\x10overall_sampling\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x0f\n\x07verbose\x18\x06 \x01(\x08\x12\x39\n\x13max_path_tag_length\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0b\x63ustom_tags\x18\x08 \x03(\x0b\x32 .envoy.type.tracing.v2.CustomTag\x12\x35\n\x08provider\x18\t \x01(\x0b\x32#.envoy.config.trace.v2.Tracing.Http\"(\n\rOperationName\x12\x0b\n\x07INGRESS\x10\x00\x12\n\n\x06\x45GRESS\x10\x01\x1a-\n\x15InternalAddressConfig\x12\x14\n\x0cunix_sockets\x18\x01 \x01(\x08\x1a\x87\x01\n\x1bSetCurrentClientCertDetails\x12+\n\x07subject\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0c\n\x04\x63\x65rt\x18\x03 \x01(\x08\x12\r\n\x05\x63hain\x18\x06 \x01(\x08\x12\x0b\n\x03\x64ns\x18\x04 \x01(\x08\x12\x0b\n\x03uri\x18\x05 \x01(\x08J\x04\x08\x02\x10\x03\x1a\xa7\x01\n\rUpgradeConfig\x12\x14\n\x0cupgrade_type\x18\x01 \x01(\t\x12S\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x42.envoy.config.filter.network.http_connection_manager.v2.HttpFilter\x12+\n\x07\x65nabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"6\n\tCodecType\x12\x08\n\x04\x41UTO\x10\x00\x12\t\n\x05HTTP1\x10\x01\x12\t\n\x05HTTP2\x10\x02\x12\t\n\x05HTTP3\x10\x03\"S\n\x1aServerHeaderTransformation\x12\r\n\tOVERWRITE\x10\x00\x12\x14\n\x10\x41PPEND_IF_ABSENT\x10\x01\x12\x10\n\x0cPASS_THROUGH\x10\x02\"y\n\x18\x46orwardClientCertDetails\x12\x0c\n\x08SANITIZE\x10\x00\x12\x10\n\x0c\x46ORWARD_ONLY\x10\x01\x12\x12\n\x0e\x41PPEND_FORWARD\x10\x02\x12\x10\n\x0cSANITIZE_SET\x10\x03\x12\x17\n\x13\x41LWAYS_FORWARD_ONLY\x10\x04\x42\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01J\x04\x08\x1b\x10\x1c\"k\n\x03Rds\x12@\n\rconfig_source\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\"\n\x11route_config_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"v\n\x1dScopedRouteConfigurationsList\x12U\n\x1bscoped_route_configurations\x18\x01 \x03(\x0b\x32&.envoy.api.v2.ScopedRouteConfigurationB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\"\xf8\x08\n\x0cScopedRoutes\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12y\n\x11scope_key_builder\x18\x02 \x01(\x0b\x32T.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilderB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x44\n\x11rds_config_source\x18\x03 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x81\x01\n scoped_route_configurations_list\x18\x04 \x01(\x0b\x32U.envoy.config.filter.network.http_connection_manager.v2.ScopedRouteConfigurationsListH\x00\x12W\n\nscoped_rds\x18\x05 \x01(\x0b\x32\x41.envoy.config.filter.network.http_connection_manager.v2.ScopedRdsH\x00\x1a\x99\x05\n\x0fScopeKeyBuilder\x12\x81\x01\n\tfragments\x18\x01 \x03(\x0b\x32\x64.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilderB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x81\x04\n\x0f\x46ragmentBuilder\x12\x9b\x01\n\x16header_value_extractor\x18\x01 \x01(\x0b\x32y.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractorH\x00\x1a\xc2\x02\n\x14HeaderValueExtractor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x19\n\x11\x65lement_separator\x18\x02 \x01(\t\x12\x0f\n\x05index\x18\x03 \x01(\rH\x00\x12\x97\x01\n\x07\x65lement\x18\x04 \x01(\x0b\x32\x83\x01.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElementH\x00\x1a=\n\tKvElement\x12\x1a\n\tseparator\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\x0e\n\x0c\x65xtract_typeB\x0b\n\x04type\x12\x03\xf8\x42\x01\x42\x17\n\x10\x63onfig_specifier\x12\x03\xf8\x42\x01\"X\n\tScopedRds\x12K\n\x18scoped_rds_config_source\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x95\x01\n\nHttpFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04\"@\n\x12RequestIDExtension\x12*\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\xaf\x01\nDio.envoyproxy.envoy.config.filter.network.http_connection_manager.v2B\x1aHttpConnectionManagerProtoP\x01\xf2\x98\xfe\x8f\x05=\x12;envoy.extensions.filters.network.http_connection_manager.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_route__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_scoped__route__pb2.DESCRIPTOR,envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,envoy_dot_type_dot_tracing_dot_v2_dot_custom__tag__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME = _descriptor.EnumDescriptor(
  name='OperationName',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.OperationName',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INGRESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGRESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3701,
  serialized_end=3741,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME)

_HTTPCONNECTIONMANAGER_CODECTYPE = _descriptor.EnumDescriptor(
  name='CodecType',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.CodecType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4098,
  serialized_end=4152,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_CODECTYPE)

_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION = _descriptor.EnumDescriptor(
  name='ServerHeaderTransformation',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ServerHeaderTransformation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERWRITE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEND_IF_ABSENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASS_THROUGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4154,
  serialized_end=4237,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION)

_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS = _descriptor.EnumDescriptor(
  name='ForwardClientCertDetails',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ForwardClientCertDetails',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SANITIZE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORWARD_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEND_FORWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SANITIZE_SET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALWAYS_FORWARD_ONLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4239,
  serialized_end=4360,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS)


_HTTPCONNECTIONMANAGER_TRACING = _descriptor.Descriptor(
  name='Tracing',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_name', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.operation_name', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\372B\005\202\001\002\020\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_for_tags', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.request_headers_for_tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_sampling', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.client_sampling', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_sampling', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.random_sampling', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall_sampling', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.overall_sampling', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.verbose', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_path_tag_length', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.max_path_tag_length', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_tags', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.custom_tags', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.provider', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3183,
  serialized_end=3741,
)

_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG = _descriptor.Descriptor(
  name='InternalAddressConfig',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.InternalAddressConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unix_sockets', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.InternalAddressConfig.unix_sockets', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3743,
  serialized_end=3788,
)

_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS = _descriptor.Descriptor(
  name='SetCurrentClientCertDetails',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails.cert', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails.chain', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails.dns', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails.uri', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3791,
  serialized_end=3926,
)

_HTTPCONNECTIONMANAGER_UPGRADECONFIG = _descriptor.Descriptor(
  name='UpgradeConfig',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_type', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig.upgrade_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig.filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig.enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3929,
  serialized_end=4096,
)

_HTTPCONNECTIONMANAGER = _descriptor.Descriptor(
  name='HttpConnectionManager',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec_type', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.codec_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.stat_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rds', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.rds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.route_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_routes', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.scoped_routes', index=4,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_filters', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.http_filters', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_user_agent', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.add_user_agent', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracing', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.tracing', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='common_http_protocol_options', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.common_http_protocol_options', index=8,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.http_protocol_options', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.http2_protocol_options', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_name', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.server_name', index=11,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_header_transformation', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.server_header_transformation', index=12,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_request_headers_kb', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.max_request_headers_kb', index=13,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030` \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.idle_timeout', index=14,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_idle_timeout', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.stream_idle_timeout', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.request_timeout', index=16,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_timeout', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.drain_timeout', index=17,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_close_timeout', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.delayed_close_timeout', index=18,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.access_log', index=19,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_remote_address', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.use_remote_address', index=20,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xff_num_trusted_hops', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.xff_num_trusted_hops', index=21,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_address_config', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.internal_address_config', index=22,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_xff_append', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.skip_xff_append', index=23,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='via', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.via', index=24,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generate_request_id', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.generate_request_id', index=25,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_external_request_id', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.preserve_external_request_id', index=26,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_client_cert_details', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.forward_client_cert_details', index=27,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_current_client_cert_details', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.set_current_client_cert_details', index=28,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_100_continue', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.proxy_100_continue', index=29,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='represent_ipv4_remote_address_as_ipv4_mapped_ipv6', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.represent_ipv4_remote_address_as_ipv4_mapped_ipv6', index=30,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrade_configs', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.upgrade_configs', index=31,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalize_path', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.normalize_path', index=32,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_slashes', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.merge_slashes', index=33,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id_extension', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.request_id_extension', index=34,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPCONNECTIONMANAGER_TRACING, _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG, _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS, _HTTPCONNECTIONMANAGER_UPGRADECONFIG, ],
  enum_types=[
    _HTTPCONNECTIONMANAGER_CODECTYPE,
    _HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION,
    _HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route_specifier', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.route_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=680,
  serialized_end=4390,
)


_RDS = _descriptor.Descriptor(
  name='Rds',
  full_name='envoy.config.filter.network.http_connection_manager.v2.Rds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_source', full_name='envoy.config.filter.network.http_connection_manager.v2.Rds.config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config_name', full_name='envoy.config.filter.network.http_connection_manager.v2.Rds.route_config_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4392,
  serialized_end=4499,
)


_SCOPEDROUTECONFIGURATIONSLIST = _descriptor.Descriptor(
  name='ScopedRouteConfigurationsList',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRouteConfigurationsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoped_route_configurations', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRouteConfigurationsList.scoped_route_configurations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4501,
  serialized_end=4619,
)


_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT = _descriptor.Descriptor(
  name='KvElement',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='separator', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement.separator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5651,
  serialized_end=5712,
)

_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR = _descriptor.Descriptor(
  name='HeaderValueExtractor',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_separator', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.element_separator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.element', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='extract_type', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.extract_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5406,
  serialized_end=5728,
)

_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER = _descriptor.Descriptor(
  name='FragmentBuilder',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_value_extractor', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.header_value_extractor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=5228,
  serialized_end=5741,
)

_SCOPEDROUTES_SCOPEKEYBUILDER = _descriptor.Descriptor(
  name='ScopeKeyBuilder',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fragments', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.fragments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5076,
  serialized_end=5741,
)

_SCOPEDROUTES = _descriptor.Descriptor(
  name='ScopedRoutes',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope_key_builder', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.scope_key_builder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rds_config_source', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.rds_config_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configurations_list', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.scoped_route_configurations_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_rds', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.scoped_rds', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_specifier', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.config_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=4622,
  serialized_end=5766,
)


_SCOPEDRDS = _descriptor.Descriptor(
  name='ScopedRds',
  full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoped_rds_config_source', full_name='envoy.config.filter.network.http_connection_manager.v2.ScopedRds.scoped_rds_config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5768,
  serialized_end=5856,
)


_HTTPFILTER = _descriptor.Descriptor(
  name='HttpFilter',
  full_name='envoy.config.filter.network.http_connection_manager.v2.HttpFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpFilter.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpFilter.typed_config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.filter.network.http_connection_manager.v2.HttpFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5859,
  serialized_end=6008,
)


_REQUESTIDEXTENSION = _descriptor.Descriptor(
  name='RequestIDExtension',
  full_name='envoy.config.filter.network.http_connection_manager.v2.RequestIDExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.filter.network.http_connection_manager.v2.RequestIDExtension.typed_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6010,
  serialized_end=6074,
)

_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['operation_name'].enum_type = _HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['client_sampling'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['random_sampling'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['overall_sampling'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['max_path_tag_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['custom_tags'].message_type = envoy_dot_type_dot_tracing_dot_v2_dot_custom__tag__pb2._CUSTOMTAG
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['provider'].message_type = envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2._TRACING_HTTP
_HTTPCONNECTIONMANAGER_TRACING.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME.containing_type = _HTTPCONNECTIONMANAGER_TRACING
_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS.fields_by_name['subject'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.fields_by_name['filters'].message_type = _HTTPFILTER
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER.fields_by_name['codec_type'].enum_type = _HTTPCONNECTIONMANAGER_CODECTYPE
_HTTPCONNECTIONMANAGER.fields_by_name['rds'].message_type = _RDS
_HTTPCONNECTIONMANAGER.fields_by_name['route_config'].message_type = envoy_dot_api_dot_v2_dot_route__pb2._ROUTECONFIGURATION
_HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'].message_type = _SCOPEDROUTES
_HTTPCONNECTIONMANAGER.fields_by_name['http_filters'].message_type = _HTTPFILTER
_HTTPCONNECTIONMANAGER.fields_by_name['add_user_agent'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['tracing'].message_type = _HTTPCONNECTIONMANAGER_TRACING
_HTTPCONNECTIONMANAGER.fields_by_name['common_http_protocol_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2._HTTPPROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['http_protocol_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['http2_protocol_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation'].enum_type = _HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION
_HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPCONNECTIONMANAGER.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['stream_idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['drain_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['delayed_close_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['access_log'].message_type = envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2._ACCESSLOG
_HTTPCONNECTIONMANAGER.fields_by_name['use_remote_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['internal_address_config'].message_type = _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG
_HTTPCONNECTIONMANAGER.fields_by_name['generate_request_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details'].enum_type = _HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS
_HTTPCONNECTIONMANAGER.fields_by_name['set_current_client_cert_details'].message_type = _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS
_HTTPCONNECTIONMANAGER.fields_by_name['upgrade_configs'].message_type = _HTTPCONNECTIONMANAGER_UPGRADECONFIG
_HTTPCONNECTIONMANAGER.fields_by_name['normalize_path'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['request_id_extension'].message_type = _REQUESTIDEXTENSION
_HTTPCONNECTIONMANAGER_CODECTYPE.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['rds'])
_HTTPCONNECTIONMANAGER.fields_by_name['rds'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['route_config'])
_HTTPCONNECTIONMANAGER.fields_by_name['route_config'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'])
_HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_RDS.fields_by_name['config_source'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations'].message_type = envoy_dot_api_dot_v2_dot_scoped__route__pb2._SCOPEDROUTECONFIGURATION
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['index'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['index'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type']
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type']
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']
_SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER.containing_type = _SCOPEDROUTES
_SCOPEDROUTES.fields_by_name['scope_key_builder'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER
_SCOPEDROUTES.fields_by_name['rds_config_source'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'].message_type = _SCOPEDROUTECONFIGURATIONSLIST
_SCOPEDROUTES.fields_by_name['scoped_rds'].message_type = _SCOPEDRDS
_SCOPEDROUTES.oneofs_by_name['config_specifier'].fields.append(
  _SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'])
_SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'].containing_oneof = _SCOPEDROUTES.oneofs_by_name['config_specifier']
_SCOPEDROUTES.oneofs_by_name['config_specifier'].fields.append(
  _SCOPEDROUTES.fields_by_name['scoped_rds'])
_SCOPEDROUTES.fields_by_name['scoped_rds'].containing_oneof = _SCOPEDROUTES.oneofs_by_name['config_specifier']
_SCOPEDRDS.fields_by_name['scoped_rds_config_source'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_HTTPFILTER.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_HTTPFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HTTPFILTER.oneofs_by_name['config_type'].fields.append(
  _HTTPFILTER.fields_by_name['config'])
_HTTPFILTER.fields_by_name['config'].containing_oneof = _HTTPFILTER.oneofs_by_name['config_type']
_HTTPFILTER.oneofs_by_name['config_type'].fields.append(
  _HTTPFILTER.fields_by_name['typed_config'])
_HTTPFILTER.fields_by_name['typed_config'].containing_oneof = _HTTPFILTER.oneofs_by_name['config_type']
_REQUESTIDEXTENSION.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['HttpConnectionManager'] = _HTTPCONNECTIONMANAGER
DESCRIPTOR.message_types_by_name['Rds'] = _RDS
DESCRIPTOR.message_types_by_name['ScopedRouteConfigurationsList'] = _SCOPEDROUTECONFIGURATIONSLIST
DESCRIPTOR.message_types_by_name['ScopedRoutes'] = _SCOPEDROUTES
DESCRIPTOR.message_types_by_name['ScopedRds'] = _SCOPEDRDS
DESCRIPTOR.message_types_by_name['HttpFilter'] = _HTTPFILTER
DESCRIPTOR.message_types_by_name['RequestIDExtension'] = _REQUESTIDEXTENSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpConnectionManager = _reflection.GeneratedProtocolMessageType('HttpConnectionManager', (_message.Message,), {

  'Tracing' : _reflection.GeneratedProtocolMessageType('Tracing', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_TRACING,
    '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing)
    })
  ,

  'InternalAddressConfig' : _reflection.GeneratedProtocolMessageType('InternalAddressConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG,
    '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.InternalAddressConfig)
    })
  ,

  'SetCurrentClientCertDetails' : _reflection.GeneratedProtocolMessageType('SetCurrentClientCertDetails', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS,
    '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails)
    })
  ,

  'UpgradeConfig' : _reflection.GeneratedProtocolMessageType('UpgradeConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_UPGRADECONFIG,
    '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig)
    })
  ,
  'DESCRIPTOR' : _HTTPCONNECTIONMANAGER,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager)
  })
_sym_db.RegisterMessage(HttpConnectionManager)
_sym_db.RegisterMessage(HttpConnectionManager.Tracing)
_sym_db.RegisterMessage(HttpConnectionManager.InternalAddressConfig)
_sym_db.RegisterMessage(HttpConnectionManager.SetCurrentClientCertDetails)
_sym_db.RegisterMessage(HttpConnectionManager.UpgradeConfig)

Rds = _reflection.GeneratedProtocolMessageType('Rds', (_message.Message,), {
  'DESCRIPTOR' : _RDS,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.Rds)
  })
_sym_db.RegisterMessage(Rds)

ScopedRouteConfigurationsList = _reflection.GeneratedProtocolMessageType('ScopedRouteConfigurationsList', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDROUTECONFIGURATIONSLIST,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRouteConfigurationsList)
  })
_sym_db.RegisterMessage(ScopedRouteConfigurationsList)

ScopedRoutes = _reflection.GeneratedProtocolMessageType('ScopedRoutes', (_message.Message,), {

  'ScopeKeyBuilder' : _reflection.GeneratedProtocolMessageType('ScopeKeyBuilder', (_message.Message,), {

    'FragmentBuilder' : _reflection.GeneratedProtocolMessageType('FragmentBuilder', (_message.Message,), {

      'HeaderValueExtractor' : _reflection.GeneratedProtocolMessageType('HeaderValueExtractor', (_message.Message,), {

        'KvElement' : _reflection.GeneratedProtocolMessageType('KvElement', (_message.Message,), {
          'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT,
          '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
          # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement)
          })
        ,
        'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR,
        '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor)
        })
      ,
      'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER,
      '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder)
      })
    ,
    'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER,
    '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder)
    })
  ,
  'DESCRIPTOR' : _SCOPEDROUTES,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes)
  })
_sym_db.RegisterMessage(ScopedRoutes)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement)

ScopedRds = _reflection.GeneratedProtocolMessageType('ScopedRds', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDRDS,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.ScopedRds)
  })
_sym_db.RegisterMessage(ScopedRds)

HttpFilter = _reflection.GeneratedProtocolMessageType('HttpFilter', (_message.Message,), {
  'DESCRIPTOR' : _HTTPFILTER,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.HttpFilter)
  })
_sym_db.RegisterMessage(HttpFilter)

RequestIDExtension = _reflection.GeneratedProtocolMessageType('RequestIDExtension', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTIDEXTENSION,
  '__module__' : 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.http_connection_manager.v2.RequestIDExtension)
  })
_sym_db.RegisterMessage(RequestIDExtension)


DESCRIPTOR._options = None
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['operation_name']._options = None
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['request_headers_for_tags']._options = None
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['codec_type']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['stat_prefix']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['idle_timeout']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details']._options = None
_RDS.fields_by_name['config_source']._options = None
_RDS.fields_by_name['route_config_name']._options = None
_SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['separator']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['key']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['name']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments']._options = None
_SCOPEDROUTES.oneofs_by_name['config_specifier']._options = None
_SCOPEDROUTES.fields_by_name['name']._options = None
_SCOPEDROUTES.fields_by_name['scope_key_builder']._options = None
_SCOPEDROUTES.fields_by_name['rds_config_source']._options = None
_SCOPEDRDS.fields_by_name['scoped_rds_config_source']._options = None
_HTTPFILTER.fields_by_name['name']._options = None
_HTTPFILTER.fields_by_name['config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/backoff.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/backoff.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\014BackoffProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/config/core/v3/backoff.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb8\x01\n\x0f\x42\x61\x63koffStrategy\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.BackoffStrategyB<\n\"io.envoyproxy.envoy.config.core.v3B\x0c\x42\x61\x63koffProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BACKOFFSTRATEGY = _descriptor.Descriptor(
  name='BackoffStrategy',
  full_name='envoy.config.core.v3.BackoffStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_interval', full_name='envoy.config.core.v3.BackoffStrategy.base_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\0012\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_interval', full_name='envoy.config.core.v3.BackoffStrategy.max_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.core.BackoffStrategy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=368,
)

_BACKOFFSTRATEGY.fields_by_name['base_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_BACKOFFSTRATEGY.fields_by_name['max_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['BackoffStrategy'] = _BACKOFFSTRATEGY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BackoffStrategy = _reflection.GeneratedProtocolMessageType('BackoffStrategy', (_message.Message,), {
  'DESCRIPTOR' : _BACKOFFSTRATEGY,
  '__module__' : 'envoy.config.core.v3.backoff_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.BackoffStrategy)
  })
_sym_db.RegisterMessage(BackoffStrategy)


DESCRIPTOR._options = None
_BACKOFFSTRATEGY.fields_by_name['base_interval']._options = None
_BACKOFFSTRATEGY.fields_by_name['max_interval']._options = None
_BACKOFFSTRATEGY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/tracers/xray/v4alpha/xray.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import address_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/tracers/xray/v4alpha/xray.proto',
  package='envoy.extensions.tracers.xray.v4alpha',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.extensions.tracers.xray.v4alphaB\tXrayProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0envoy/extensions/tracers/xray/v4alpha/xray.proto\x12%envoy.extensions.tracers.xray.v4alpha\x1a\'envoy/config/core/v4alpha/address.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb5\x03\n\nXRayConfig\x12\x41\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32(.envoy.config.core.v4alpha.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x45\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSource\x12W\n\x0esegment_fields\x18\x04 \x01(\x0b\x32?.envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields\x1a|\n\rSegmentFields\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12$\n\x03\x61ws\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:5\x9a\xc5\x88\x1e\x30\n.envoy.config.trace.v3.XRayConfig.SegmentFields:\'\x9a\xc5\x88\x1e\"\n envoy.config.trace.v3.XRayConfigBJ\n3io.envoyproxy.envoy.extensions.tracers.xray.v4alphaB\tXrayProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_XRAYCONFIG_SEGMENTFIELDS = _descriptor.Descriptor(
  name='SegmentFields',
  full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields.origin', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields.aws', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.trace.v3.XRayConfig.SegmentFields',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=688,
)

_XRAYCONFIG = _descriptor.Descriptor(
  name='XRayConfig',
  full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='daemon_endpoint', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.daemon_endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_name', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.segment_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_rule_manifest', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.sampling_rule_manifest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_fields', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.segment_fields', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_XRAYCONFIG_SEGMENTFIELDS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.config.trace.v3.XRayConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=729,
)

_XRAYCONFIG_SEGMENTFIELDS.fields_by_name['aws'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_XRAYCONFIG_SEGMENTFIELDS.containing_type = _XRAYCONFIG
_XRAYCONFIG.fields_by_name['daemon_endpoint'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._SOCKETADDRESS
_XRAYCONFIG.fields_by_name['sampling_rule_manifest'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_XRAYCONFIG.fields_by_name['segment_fields'].message_type = _XRAYCONFIG_SEGMENTFIELDS
DESCRIPTOR.message_types_by_name['XRayConfig'] = _XRAYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

XRayConfig = _reflection.GeneratedProtocolMessageType('XRayConfig', (_message.Message,), {

  'SegmentFields' : _reflection.GeneratedProtocolMessageType('SegmentFields', (_message.Message,), {
    'DESCRIPTOR' : _XRAYCONFIG_SEGMENTFIELDS,
    '__module__' : 'envoy.extensions.tracers.xray.v4alpha.xray_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields)
    })
  ,
  'DESCRIPTOR' : _XRAYCONFIG,
  '__module__' : 'envoy.extensions.tracers.xray.v4alpha.xray_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.xray.v4alpha.XRayConfig)
  })
_sym_db.RegisterMessage(XRayConfig)
_sym_db.RegisterMessage(XRayConfig.SegmentFields)


DESCRIPTOR._options = None
_XRAYCONFIG_SEGMENTFIELDS._options = None
_XRAYCONFIG.fields_by_name['segment_name']._options = None
_XRAYCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/certs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/certs.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\nCertsProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/admin/v2alpha/certs.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"F\n\x0c\x43\x65rtificates\x12\x36\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32 .envoy.admin.v2alpha.Certificate\"\x84\x01\n\x0b\x43\x65rtificate\x12\x38\n\x07\x63\x61_cert\x18\x01 \x03(\x0b\x32\'.envoy.admin.v2alpha.CertificateDetails\x12;\n\ncert_chain\x18\x02 \x03(\x0b\x32\'.envoy.admin.v2alpha.CertificateDetails\"\x83\x02\n\x12\x43\x65rtificateDetails\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x44\n\x11subject_alt_names\x18\x03 \x03(\x0b\x32).envoy.admin.v2alpha.SubjectAlternateName\x12\x1d\n\x15\x64\x61ys_until_expiration\x18\x04 \x01(\x04\x12.\n\nvalid_from\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"R\n\x14SubjectAlternateName\x12\r\n\x03\x64ns\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x14\n\nip_address\x18\x03 \x01(\tH\x00\x42\x06\n\x04nameB9\n!io.envoyproxy.envoy.admin.v2alphaB\nCertsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CERTIFICATES = _descriptor.Descriptor(
  name='Certificates',
  full_name='envoy.admin.v2alpha.Certificates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='envoy.admin.v2alpha.Certificates.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=190,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='envoy.admin.v2alpha.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca_cert', full_name='envoy.admin.v2alpha.Certificate.ca_cert', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert_chain', full_name='envoy.admin.v2alpha.Certificate.cert_chain', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=325,
)


_CERTIFICATEDETAILS = _descriptor.Descriptor(
  name='CertificateDetails',
  full_name='envoy.admin.v2alpha.CertificateDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.admin.v2alpha.CertificateDetails.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='envoy.admin.v2alpha.CertificateDetails.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_alt_names', full_name='envoy.admin.v2alpha.CertificateDetails.subject_alt_names', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days_until_expiration', full_name='envoy.admin.v2alpha.CertificateDetails.days_until_expiration', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_from', full_name='envoy.admin.v2alpha.CertificateDetails.valid_from', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='envoy.admin.v2alpha.CertificateDetails.expiration_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=587,
)


_SUBJECTALTERNATENAME = _descriptor.Descriptor(
  name='SubjectAlternateName',
  full_name='envoy.admin.v2alpha.SubjectAlternateName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.admin.v2alpha.SubjectAlternateName.dns', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.admin.v2alpha.SubjectAlternateName.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='envoy.admin.v2alpha.SubjectAlternateName.ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SubjectAlternateName.name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=589,
  serialized_end=671,
)

_CERTIFICATES.fields_by_name['certificates'].message_type = _CERTIFICATE
_CERTIFICATE.fields_by_name['ca_cert'].message_type = _CERTIFICATEDETAILS
_CERTIFICATE.fields_by_name['cert_chain'].message_type = _CERTIFICATEDETAILS
_CERTIFICATEDETAILS.fields_by_name['subject_alt_names'].message_type = _SUBJECTALTERNATENAME
_CERTIFICATEDETAILS.fields_by_name['valid_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS.fields_by_name['expiration_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['dns'])
_SUBJECTALTERNATENAME.fields_by_name['dns'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['uri'])
_SUBJECTALTERNATENAME.fields_by_name['uri'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['ip_address'])
_SUBJECTALTERNATENAME.fields_by_name['ip_address'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
DESCRIPTOR.message_types_by_name['Certificates'] = _CERTIFICATES
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['CertificateDetails'] = _CERTIFICATEDETAILS
DESCRIPTOR.message_types_by_name['SubjectAlternateName'] = _SUBJECTALTERNATENAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Certificates = _reflection.GeneratedProtocolMessageType('Certificates', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATES,
  '__module__' : 'envoy.admin.v2alpha.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.Certificates)
  })
_sym_db.RegisterMessage(Certificates)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATE,
  '__module__' : 'envoy.admin.v2alpha.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.Certificate)
  })
_sym_db.RegisterMessage(Certificate)

CertificateDetails = _reflection.GeneratedProtocolMessageType('CertificateDetails', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEDETAILS,
  '__module__' : 'envoy.admin.v2alpha.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.CertificateDetails)
  })
_sym_db.RegisterMessage(CertificateDetails)

SubjectAlternateName = _reflection.GeneratedProtocolMessageType('SubjectAlternateName', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTALTERNATENAME,
  '__module__' : 'envoy.admin.v2alpha.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SubjectAlternateName)
  })
_sym_db.RegisterMessage(SubjectAlternateName)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/ratelimit/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/ratelimit/ratelimit.proto',
  package='envoy.api.v2.ratelimit',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.api.v2.ratelimitB\016RatelimitProtoP\001\362\230\376\217\005&\022$envoy.extensions.common.ratelimit.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/api/v2/ratelimit/ratelimit.proto\x12\x16\x65nvoy.api.v2.ratelimit\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9a\x01\n\x13RateLimitDescriptor\x12L\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x31.envoy.api.v2.ratelimit.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42l\n$io.envoyproxy.envoy.api.v2.ratelimitB\x0eRatelimitProtoP\x01\xf2\x98\xfe\x8f\x05&\x12$envoy.extensions.common.ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMITDESCRIPTOR_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=309,
)

_RATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='RateLimitDescriptor',
  full_name='envoy.api.v2.ratelimit.RateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITDESCRIPTOR_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=309,
)

_RATELIMITDESCRIPTOR_ENTRY.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
DESCRIPTOR.message_types_by_name['RateLimitDescriptor'] = _RATELIMITDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitDescriptor = _reflection.GeneratedProtocolMessageType('RateLimitDescriptor', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_ENTRY,
    '__module__' : 'envoy.api.v2.ratelimit.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.ratelimit.RateLimitDescriptor.Entry)
    })
  ,
  'DESCRIPTOR' : _RATELIMITDESCRIPTOR,
  '__module__' : 'envoy.api.v2.ratelimit.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.ratelimit.RateLimitDescriptor)
  })
_sym_db.RegisterMessage(RateLimitDescriptor)
_sym_db.RegisterMessage(RateLimitDescriptor.Entry)


DESCRIPTOR._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
_RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/sensitive.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/annotations/sensitive.proto',
  package='udpa.annotations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n udpa/annotations/sensitive.proto\x12\x10udpa.annotations\x1a google/protobuf/descriptor.proto:3\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xf7\xb6\xc1$ \x01(\x08\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


SENSITIVE_FIELD_NUMBER = 76569463
sensitive = _descriptor.FieldDescriptor(
  name='sensitive', full_name='udpa.annotations.sensitive', index=0,
  number=76569463, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.extensions_by_name['sensitive'] = sensitive
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)

# @@protoc_insertion_point(module_scope)
